---
author:
- Mathématiques en technologie de l'information
title: Travail pratique - Les transformées de Fourier
autoSectionLabels: false
autoEqnLabels: true
eqnPrefix:
    - "éq."
    - "éqs."
chapters: true
numberSections: false
chaptersDepth: 1
sectionsDepth: 3
lang: fr
documentclass: article
papersize: A4
cref: false
urlcolor: blue
toc: false
include-before: <script src="css/prism.js"></script>
---
\newcommand{\dd}{\mathrm{d}}
\newcommand{\real}{\mathbb{R}}
\newcommand{\integer}{\mathbb{Z}}
\renewcommand{\natural}{\mathbb{N}}
\newcommand{\complex}{\mathbb{C}}

# Objectif

Implémenter de façon naïve les transformées de Fourier discrètes
en deux dimensions et comprendre leur utilité en traitement d'image.
Puis comparer les performances de votre implémentation avec
cellee de la librairie `numpy`.

# Les transformées de Fourier en plusieurs dimensions

Nous avons vu pendant le cours la définition de la transformée de Fourier discrète
en une dimension donc nous n'allons pas trop insister sur le sujet ici
mais reproduire le résulta principal.

Soit un signal $f[n]$ discret et de longueur $N$ ($n$ va de $0$ à $N-1$),
nous pouvons écrire sa transformée, $\hat{f}[k]$ ($k$ allant de $0,..,N-1$) de Fourier comme[^1]
$$
{\hat{f}}[k]=\sum_{n=0}^{N-1} f[n] e^{-\frac{2\pi i n k}{N}}.
$$
A l'inverse, on peut calculer la transformées de Fourier discrète inverse de $\hat{f}[k]$ comme
$$
f[n]=\frac{1}{N}\sum_{k=0}^{N-1} {\hat{f}}[k] e^{\frac{2\pi i k n}{N}},
$$
ce qui permet de déterminer le signal d'origine à partir de sa transformée de Fourier.

On peut généraliser la transformée de Fourier pour des signaux en plus d'une dimension.
Ici, on va s'intéresser aux signaux bidimensionnels. Un tel signal peut représenter
par exemple les niveaux de gris d'une image. On a que la transformée de Fourier
pour un signal qui dépend de deux coordonnées, $f[n_1,n_2]$, $n_1=0,..,N_1-1$, $n_2=0,..,N_2-1$,
a une transformée de Fourier discrète, $\hat{f}[k_1,k_2]$, $k_1=0,..,N_1-1$ et $k_2=0,..,N_2-1$, donnée par
$$
{\hat{f}}[k_1,k_2]=\sum_{n_1=0}^{N_1-1} e^{-\frac{2\pi i n_1 k_1}{N_1}}\left(\sum_{n_2=0}^{N_2-1} f[n_1,n_2] e^{-\frac{2\pi i n_2 k_2}{N_2}}\right).
$$
De cette formule, on peut déduire que faire la transformée de Fourier en deux dimensions
n'est rien d'autre que faire la transformée de Fourier dans chacune des dimensions
séparément.

De même la transformée de Fourier inverse à deux dimensions s'écrit
$$
f[n_1,n_2]=\sum_{k_1=0}^{N_1-1} e^{\frac{2\pi i n_1 k_1}{N_1}}\left(\sum_{k_2=0}^{N_2-1} {\hat{f}}[k_1,k_2] e^{\frac{2\pi i n_2 k_2}{N_2}}\right).
$$

On peut donc faire une analyse de Fourier d'une image presque aussi facilement qu'on le ferait pour un signal unidimensionnel.

# Travail à réaliser

# Conseils

Les librairies `python` que j'ai essayée pour ce TP sont:

1. `numpy` pour les manipulations de matrices et le calcul de TFR (les fonctions `fft.ifft2()`{.language-python} et `fft.fft2()`).
2. `imageio` pour la manipulation d'images (en particulier `imread()` et `imwrite()`).
3. `matplotlib` pour la visualisation des images et ds spectres (en particulier `pyplot.imshow()` et `plot_surface()` respectivement).

[^1]: On représente $f[n]$ et $\hat{f}[k]$ comme des listes (ou vecteurs) de longueur $N$.